import { sql, type InferSelectModel } from 'drizzle-orm';
import { foreignKey, index, integer, primaryKey, sqliteTable, text } from 'drizzle-orm/sqlite-core';

const createdAt = integer('created_at', { mode: 'timestamp_ms' })
  .notNull()
  .default(sql`(unixepoch('subsec') * 1000)`)
  .$defaultFn(() => new Date());
const updatedAt = integer('updated_at', { mode: 'timestamp_ms' })
  .notNull()
  .default(sql`(unixepoch('subsec') * 1000)`)
  .$onUpdateFn(() => new Date());

export const users = sqliteTable(
  'users',
  {
    id: text('id').primaryKey(),
    email: text('email').notNull().unique(),
    name: text('name').notNull(),
    hash: text('hash').notNull(),
    createdAt,
    updatedAt,
  }
);

export const userSessions = sqliteTable(
  'user_sessions',
  {
    token: text('token').primaryKey().unique(),
    userId: text('user_id').notNull(),
    maxAge: integer('max_age', { mode: 'number' }).notNull(),
    createdAt,
    updatedAt,
  },
  (t) => [
    foreignKey({ columns: [t.userId], foreignColumns: [users.id] }).onDelete('cascade'),
  ],
);
